@@ -25,39 +25,15 @@ get_makefile_txt <- function() {
   # Return: 
   #   a character vector in which each element is a line of 
   #   the makefile 
-  WINDOWS <- .Platform$OS.type == "windows"
-  rarch <- Sys.getenv("R_ARCH") # unix only
-  if (WINDOWS && nzchar(.Platform$r_arch))
-    rarch <- paste0("/", .Platform$r_arch)
-  site <- file.path(R.home("etc"), rarch, "Makevars.site")
-
-  sys_makeconf <- file.path(R.home("etc"), rarch, "Makeconf")
-  if (!file.exists(sys_makeconf)) 
-    stop(paste("file ", sys_makeconf, " does not exist", sep = '')) 
-  makefiles <-
-    c(sys_makeconf, 
-      if (file.exists(site)) site,
-      file.path(R.home("share"), "make", if (WINDOWS) "winshlib.mk" else "shlib.mk"))
-
-  if (WINDOWS) { 
-    if (rarch == "/x64" && 
-        file.exists(f <- path.expand("~/.R/Makevars.win64"))) 
-      makefiles <- c(makefiles, f) 
-    else if (file.exists(f <- path.expand("~/.R/Makevars.win"))) 
-      makefiles <- c(makefiles, f) 
-    else if (file.exists(f <- path.expand("~/.R/Makevars"))) 
-      makefiles <- c(makefiles, f) 
-  } else { 
-    if (file.exists(f <- path.expand(paste("~/.R/Makevars", 
-                                            Sys.getenv("R_PLATFORM"), 
-                                            sep = "-")))) 
-       makefiles <- c(makefiles, f) 
-    else if (file.exists(f <- path.expand("~/.R/Makevars"))) 
-       makefiles <- c(makefiles, f) 
-  }
+  out <- system2(file.path(Sys.getenv("R_HOME"), "bin", "R"),
+                 args = "CMD SHLIB --dry-run", stdout = TRUE)[2]
+  makefiles <- strsplit(sub("SHLIB.*$", "", out), split = "-f ")[[1]][-1]
+  makefiles <- gsub("'", "", makefiles)
+  makefiles <- gsub("[[:space:]]*$", "", makefiles)
+  makefiles <- gsub('\"', '', makefiles)
   makefiles <- makefiles[file.exists(makefiles)]
   do.call(c, lapply(makefiles, function(f) readLines(f, warn = FALSE))) 
-} 
+}
 
 get_makefile_flags <- function(FLAGNAME, makefile_txt, headtotail = FALSE) { 
   # get current CXXFLAGS used for in R CMD SHLIB, which controls
